package ch.unil.bonita;

import java.io.Serializable;

public class Hotel implements Serializable{
	private static final long serialVersionUID = 1L;

	private Integer hotelId;
	private String name;
	private String address1;
	private String city;
	private String stateProvinceCode;
	private Integer postalCode;
	private String countryCode;
	private String airportCode;
	private String propertyCategory;
	private Float hotelRating;
	private String confidenceRating;
	private Float tripAdvisorRating;
	private String locationDescription;
	private String shortDescription;
	private Float highRate;
	private Float lowRate;
	private String rateCurrencyCode;
	private String latitude;
	private String longitude;
	private Float proximityDistance;
	private String proximityUnit;
	private Boolean hotelInDestination;
	private String thumbNailUrl;
	private String deepLink;
		
	public Hotel(){
		
	}
	
	/**
	 * Create a Hotel instance populated with the xml data rootNode is &lt;HotelSummary&gt;
	 * 
	 * @param xml &lt;HotelSummary&gt; Node
	 */
	public Hotel(groovy.util.slurpersupport.NodeChild xml){
		xml.children().each{ attribute ->
			try{
				def type = this.class.getDeclaredField(attribute.name()).getType()
				this."${attribute.name()}" = type.valueOf(attribute.text())
			}catch(NoSuchFieldException ex){
			
			}
		}
	}
	
	public String toString(){
		return "$name (${hotelId}) $city" 
	}
	
	/**
	* Returns an HTML representation of the Hotel
	* the outermost div has the class isie_hotel
	*
	* @return HTML code
	*/
	public String toHtml(){
		def out = new StringWriter();
		def html = new groovy.xml.MarkupBuilder(out)
		html.div(['class': 'isie_hotel']){
			h4("$name (${hotelId})")
			div("$address1\n$postalCode $city\n$countryCode")
			div("Description: $shortDescription")
			div("Price: $lowRate - $highRate $rateCurrencyCode")
			div("Rating: $hotelRating")
		}
		return out.toString();
	}
	
	
	//manually write getter/setter for them to show up in bonita....
	
	public Integer getHotelId() {
		return hotelId;
	}

	public void setHotelId(Integer hotelId) {
		this.hotelId = hotelId;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getAddress1() {
		return address1;
	}

	public void setAddress1(String address) {
		this.address1 = address;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getStateProvinceCode() {
		return stateProvinceCode;
	}

	public void setStateProvinceCode(String stateProvinceCode) {
		this.stateProvinceCode = stateProvinceCode;
	}

	public Integer getPostalCode() {
		return postalCode;
	}

	public void setPostalCode(Integer postalCode) {
		this.postalCode = postalCode;
	}

	public String getCountryCode() {
		return countryCode;
	}

	public void setCountryCode(String countryCode) {
		this.countryCode = countryCode;
	}

	public String getAirportCode() {
		return airportCode;
	}

	public void setAirportCode(String airportCode) {
		this.airportCode = airportCode;
	}

	public String getPropertyCategory() {
		return propertyCategory;
	}

	public void setPropertyCategory(String propertyCategory) {
		this.propertyCategory = propertyCategory;
	}

	public Float getHotelRating() {
		return hotelRating;
	}

	public void setHotelRating(Float hotelRating) {
		this.hotelRating = hotelRating;
	}

	public String getConfidenceRating() {
		return confidenceRating;
	}

	public void setConfidenceRating(String confidenceRating) {
		this.confidenceRating = confidenceRating;
	}

	public Float getTripAdvisorRating() {
		return tripAdvisorRating;
	}

	public void setTripAdvisorRating(Float tripAdvisorRating) {
		this.tripAdvisorRating = tripAdvisorRating;
	}

	public String getLocationDescription() {
		return locationDescription;
	}

	public void setLocationDescription(String locationDescription) {
		this.locationDescription = locationDescription;
	}

	public String getShortDescription() {
		return shortDescription;
	}

	public void setShortDescription(String shortDescription) {
		this.shortDescription = shortDescription;
	}

	public Float getHighRate() {
		return highRate;
	}

	public void setHighRate(Float highRate) {
		this.highRate = highRate;
	}

	public Float getLowRate() {
		return lowRate;
	}

	public void setLowRate(Float lowRate) {
		this.lowRate = lowRate;
	}

	public String getRateCurrencyCode() {
		return rateCurrencyCode;
	}

	public void setRateCurrencyCode(String rateCurrencyCode) {
		this.rateCurrencyCode = rateCurrencyCode;
	}

	public String getLatitude() {
		return latitude;
	}

	public void setLatitude(String latitude) {
		this.latitude = latitude;
	}

	public String getLongitude() {
		return longitude;
	}

	public void setLongitude(String longitude) {
		this.longitude = longitude;
	}

	public Float getProximityDistance() {
		return proximityDistance;
	}

	public void setProximityDistance(Float proximityDistance) {
		this.proximityDistance = proximityDistance;
	}

	public String getProximityUnit() {
		return proximityUnit;
	}

	public void setProximityUnit(String proximityUnit) {
		this.proximityUnit = proximityUnit;
	}

	public Boolean getHotelInDestination() {
		return hotelInDestination;
	}

	public void setHotelInDestination(Boolean hotelInDestination) {
		this.hotelInDestination = hotelInDestination;
	}

	public String getThumbNailUrl() {
		return thumbNailUrl;
	}

	public void setThumbNailUrl(String thumbNailUrl) {
		this.thumbNailUrl = thumbNailUrl;
	}

	public String getDeepLink() {
		return deepLink;
	}

	public void setDeepLink(String deepLink) {
		this.deepLink = deepLink;
	}

}
